@@ -8,10 +8,9 @@
 //!
 //! Serde is supported. If you need pre-computed length at serialization time
 //! (for example, for bincode), use `serde_ser_len` feature.
-
-
-#[cfg(test)]
-mod test;
+//!
+//! If you are worried about losing strict typing advantages because of those 
+//! `usize`s, you can use [special wrapper](wrapped/struct.CompactMap.html)
 
 use std::mem;
 use std::usize;
@@ -180,6 +179,7 @@ impl<V> CompactMap<V> {
 
     /// Removes a key from the map, returning the value at the key if the key
     /// was previously in the map.
+    ///
     /// ```
     /// use compactmap::CompactMap;
     ///
@@ -849,3 +849,12 @@ mod serdizer {
         }
     }
 }
+
+/// Special version of CompactMap that helps you not to confuse those `usize` tokens
+/// with something else
+#[macro_use]
+pub mod wrapped;
+
+
+#[cfg(test)]
+mod test;
